@@ -28,11 +28,14 @@ import re
 
 from .. import (
     branch as _mod_branch,
+    controldir,
     debug,
     errors,
     lazy_import,
     osutils,
     revision,
+    trace,
+    transport as _mod_transport,
     )
 from ..controldir import (
     ControlDir,
@@ -49,9 +52,6 @@ from ..revisiontree import (
 lazy_import.lazy_import(globals(), """
 from breezy import (
     add,
-    controldir,
-    trace,
-    transport as _mod_transport,
     )
 from breezy.bzr import (
     inventory as _mod_inventory,
@@ -144,6 +144,8 @@ class InventoryTree(Tree):
     root_inventory = property(_get_root_inventory,
                               doc="Root inventory of this tree")
 
+    supports_file_ids = True
+
     def _unpack_file_id(self, file_id):
         """Find the inventory and inventory file id for a tree file id.
 
@@ -209,6 +211,10 @@ class InventoryTree(Tree):
         with self.lock_read():
             return self._path2inv_file_id(path)[1]
 
+
+    def is_versioned(self, path):
+        return self.path2id(path) is not None
+
     def _path2ie(self, path):
         """Lookup an inventory entry by path.
 
@@ -217,7 +223,7 @@ class InventoryTree(Tree):
         """
         inv, ie = self._path2inv_ie(path)
         if ie is None:
-            raise errors.NoSuchFile(path)
+            raise _mod_transport.NoSuchFile(path)
         return ie
 
     def _path2inv_ie(self, path):
@@ -296,9 +302,11 @@ class InventoryTree(Tree):
             def iter_entries(inv):
                 for p, e in inv.iter_entries_by_dir(specific_file_ids=inventory_file_ids):
                     if e.kind == 'tree-reference' and recurse_nested:
-                        subinv = self._get_nested_tree(p, e.file_id, e.reference_revision).root_inventory
-                        for subp, e in iter_entries(subinv):
-                            yield (osutils.pathjoin(p, subp) if subp else p), e
+                        subtree = self._get_nested_tree(p, e.file_id, e.reference_revision)
+                        with subtree.lock_read():
+                            subinv = subtree.root_inventory
+                            for subp, e in iter_entries(subinv):
+                                yield (osutils.pathjoin(p, subp) if subp else p), e
                     else:
                         yield p, e
             return iter_entries(self.root_inventory)
@@ -610,6 +618,75 @@ class MutableInventoryTree(MutableTree, InventoryTree):
         from .transform import InventoryTreeTransform
         return InventoryTreeTransform(self, pb=pb)
 
+    def add(self, files, kinds=None, ids=None):
+        """Add paths to the set of versioned paths.
+
+        Note that the command line normally calls smart_add instead,
+        which can automatically recurse.
+
+        This adds the files to the tree, so that they will be
+        recorded by the next commit.
+
+        Args:
+          files: List of paths to add, relative to the base of the tree.
+          kinds: Optional parameter to specify the kinds to be used for
+            each file.
+          ids: If set, use these instead of automatically generated ids.
+            Must be the same length as the list of files, but may
+            contain None for ids that are to be autogenerated.
+
+        TODO: Perhaps callback with the ids and paths as they're added.
+        """
+        if isinstance(files, str):
+            # XXX: Passing a single string is inconsistent and should be
+            # deprecated.
+            if not (ids is None or isinstance(ids, bytes)):
+                raise AssertionError()
+            if not (kinds is None or isinstance(kinds, str)):
+                raise AssertionError()
+            files = [files]
+            if ids is not None:
+                ids = [ids]
+            if kinds is not None:
+                kinds = [kinds]
+
+        files = [path.strip('/') for path in files]
+
+        if ids is None:
+            ids = [None] * len(files)
+        else:
+            if not (len(ids) == len(files)):
+                raise AssertionError()
+        if kinds is None:
+            kinds = [None] * len(files)
+        elif not len(kinds) == len(files):
+            raise AssertionError()
+        with self.lock_tree_write():
+            for f in files:
+                # generic constraint checks:
+                if self.is_control_filename(f):
+                    raise errors.ForbiddenControlFileError(filename=f)
+                fp = osutils.splitpath(f)
+            # fill out file kinds for all files [not needed when we stop
+            # caring about the instantaneous file kind within a uncommmitted tree
+            #
+            self._gather_kinds(files, kinds)
+            self._add(files, kinds, ids)
+
+    def _gather_kinds(self, files, kinds):
+        """Helper function for add - sets the entries of kinds."""
+        raise NotImplementedError(self._gather_kinds)
+
+    def _add(self, files, kinds, ids):
+        """Helper function for add - updates the inventory.
+
+        :param files: sequence of pathnames, relative to the tree root
+        :param kinds: sequence of  inventory kinds of the files (i.e. may
+            contain "tree-reference")
+        :param ids: sequence of suggested ids for the files (may be None)
+        """
+        raise NotImplementedError(self._add)
+
 
 class _SmartAddHelper(object):
     """Helper for MutableTree.smart_add."""
@@ -987,7 +1064,7 @@ class InventoryRevisionTree(RevisionTree, InventoryTree):
         """See Tree.path_content_summary."""
         try:
             entry = self._path2ie(path)
-        except errors.NoSuchFile:
+        except _mod_transport.NoSuchFile:
             return ('missing', None, None, None)
         kind = entry.kind
         if kind == 'file':
@@ -1038,7 +1115,7 @@ class InventoryRevisionTree(RevisionTree, InventoryTree):
             for result in self._repository.iter_files_bytes(repo_desired_files):
                 yield result
         except errors.RevisionNotPresent as e:
-            raise errors.NoSuchFile(e.file_id)
+            raise _mod_transport.NoSuchFile(e.file_id)
 
     def annotate_iter(self, path, default_revision=revision.CURRENT_REVISION):
         """See Tree.annotate_iter"""
@@ -1428,7 +1505,7 @@ class InterInventoryTree(InterTree):
         """
         file_id = self.source.path2id(path)
         if file_id is None:
-            raise errors.NoSuchFile(path)
+            raise _mod_transport.NoSuchFile(path)
         try:
             return self.target.id2path(file_id, recurse=recurse)
         except errors.NoSuchId:
@@ -1443,7 +1520,7 @@ class InterInventoryTree(InterTree):
         """
         file_id = self.target.path2id(path)
         if file_id is None:
-            raise errors.NoSuchFile(path)
+            raise _mod_transport.NoSuchFile(path)
         try:
             return self.source.id2path(file_id, recurse=recurse)
         except errors.NoSuchId:
